
;; #+begin_src emacs-lisp :tangle yes :comments org
;;   (defun org-

(defun org-babel-comment-delete-drawers ()
  "Delete drawer delimiters and contents from comment.
Drawer names are restricted to those in the `org-drawers' state."
  (let ((drawer-start-regexp
         (format "^[ \t]*:\\(?:%s\\):[ \t]*$"
                 (mapconcat 'identity
                            org-drawers
                            "\\|")))
        (drawer-end-regexp "^[ \t]*:END:[ \t]*$"))
    (while (re-search-forward drawer-start-regexp nil t)
      (let ((beg (save-excursion
                   (forward-line 0)
                   (point)))
            (end (save-excursion
                   (re-search-forward drawer-end-regexp nil t)
                   (forward-line 1)
                   (point))))
        (goto-char end)
        (delete-region beg end)))))

(defun org-babel-comment-delete-drawer-delimiters ()
  "Delete drawer delimiters from comment leaving content.
Drawer names are restricted to those given by the `org-drawers'
state."
  (let ((drawer-delim-regexp
         (format "^[ \t]*:\\(?:%s\\)"
                 (mapconcat 'identity
                            (cons "END" org-drawers)
                            "\\|"))))
    (delete-matching-lines drawer-delim-regexp)))

(defun org-babel-comment-delete-org-control-lines ()
  "Remove all org #+ control lines from comment."
  (let ((control-regexp "^[ \t]*#\\+.*$"))
    (delete-matching-lines control-regexp)))

;; Perhaps the all caps are not required, need an official regexp here.

(defun org-babel-comment-delete-org-in-buffer-settings ()
  "Remove all org #+ in-buffer setting lines, leaving other control lines.
In-buffer setting lines begin with #+ and have all caps keyword
names."
  (let ((setting-regexp "^#\\+[ \t]*[A-Z_]+:.*$"))
    (delete-matching-lines setting-regexp)))

;; *** Is there a core emacs function for this?
;; 
;;     =delete-blank-lines= is not quite right.
;;     :PROPERTIES:
;;     :CHECKING: no
;;     :WORKS: yes
;;     :END:

(defun org-babel-comment-trim-blank-lines ()
  "Trim whitespace-only lines from beginning and end of text."
  (while (and (looking-at "^[ \t\f]*$")
              (< (point) (point-max)))
    (forward-line 1))
  (delete-region (point-min) (point))
  (when (< (point) (point-max))
    (goto-char (point-max))
    (let ((last-point (point)))
      (forward-line 0)
      (while (and (looking-at "^[ \t\f]*$")
                  (> (point) (point-min)))
        (setq last-point (point))
        (forward-line -1))
      (delete-region last-point (point-max)))))
